#
# spec file for package tk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tk
BuildRequires:  imake
BuildRequires:  libX11-devel
BuildRequires:  libXScrnSaver-devel
BuildRequires:  libXft-devel
BuildRequires:  libXt-devel
BuildRequires:  pkg-config
BuildRequires:  tcl-devel
Url:            http://www.tcl.tk
Version:        8.6.7
Release:        lp152.4.6.1
%define         rrc %nil
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Graphical User Interface Toolkit for Tcl
License:        TCL
Group:          Development/Languages/Tcl
Obsoletes:      tkcon < 2.7
Provides:       tkcon = 2.7
# bug437293
%ifarch ppc64
Obsoletes:      tk-64bit
%endif
#
Provides:       wish
Provides:       wish8.6
Requires:       tcl >= %version
Requires:       xhost
PreReq:         /bin/rm
Source0:        ftp://ftp.tcl.tk/pub/tcl/tcl8_6/%name%{version}%{rrc}-src.tar.gz
Source1:        tk-rpmlintrc
Source2:        baselibs.conf
Source3:        http://tkcon.cvs.sourceforge.net/tkcon/tkcon/tkcon.tcl
Patch0:         %name.patch
Patch1:         tk-8.5.12-fix-xft.patch

%description
Tk is a graphical user interface toolkit that takes developing desktop
applications to a higher level than conventional approaches. Tk is the
standard GUI not only for Tcl, but for many other dynamic languages,
and can produce rich, native applications that run unchanged across
Windows, Mac OS X, Linux and more.



Authors:
--------
    The Tcl Core Team <tcl-core@lists.sourceforge.net>

%package devel
Summary:        Header Files and C API Documentation for Tk
Group:          Development/Libraries/Tcl
Requires:       tcl-devel
Requires:       tk = %version
Requires:       xorg-x11-libX11-devel
# bug437293
%ifarch ppc64
Obsoletes:      tk-devel-64bit
%endif
#

%description devel
This package contains header files and documentation needed for writing
Tk extensions in compiled languages like C, C++, etc., or for embedding
Tk in programs written in such languages.

This package is not needed for writing extensions or applications for
Tk in the Tcl language itself.



Authors:
--------
    The Tcl Core Team <tcl-core@lists.sourceforge.net>

%define TK_MINOR %(echo %version | cut -c1-3)
%define scriptdir %(echo 'puts -nonewline [file dirname $tcl_library]' | tclsh)/tk%TK_MINOR

%prep
%setup -q -n %name%version
%patch0
%patch1 -p1

%build
cd unix
%configure \
	--with-tcl=%_libdir \
	--enable-threads \
	--enable-man-symlinks \
	--enable-man-compression=gzip
make %{?_smp_mflags} \
	TK_LIBRARY="%scriptdir" \
	TK_PKG_DIR="tcl/tk%TK_MINOR"

%install
# these renamings are needed to avoid some file name clashes with other packages
mv doc/menubar.n doc/tk_menubar.n
mv doc/dialog.n doc/tk_dialog.n
mv doc/panedwindow.n doc/tk_panedwindow.n
make -C unix install install-private-headers \
	INSTALL_ROOT=%buildroot \
	TK_LIBRARY="%scriptdir" \
	TK_PKG_DIR="tcl/tk%TK_MINOR"
ln -sf wish%TK_MINOR %buildroot%_prefix/bin/wish
ln -sf wish%TK_MINOR.n.gz %buildroot%_mandir/mann/wish.n.gz
install -m 0755 %{S:3} %buildroot%_bindir/tkcon
# The information in TK_LIBS is not needed for shared libraries
# and we don't support static linking.
sed -i "/^TK_LIBS=/s/'.*'$//" %buildroot%_libdir/tkConfig.sh
sed -i "/^Libs.private: /s/ .*$//" %buildroot%_libdir/pkgconfig/tk.pc

%if %_lib == lib64

%post
test -L /usr/lib/tk%TK_MINOR && rm -f /usr/lib/tk%TK_MINOR
exit 0
%endif

%files
%defattr(-,root,root)
%doc README changes license.terms ChangeLog*
%docdir %_mandir/mann
%doc %_mandir/man1/*
%doc %_mandir/mann/*
%_prefix/bin/*
%_libdir/*.so
%scriptdir
%exclude %scriptdir/tkAppInit.c

%files devel
%defattr(-,root,root)
%doc %_mandir/man3/*
%_prefix/include/*
%scriptdir/tkAppInit.c
%attr(0644,root,root) %_libdir/*.a
%_libdir/tkConfig.sh
%_libdir/pkgconfig/*

%changelog
* Fri Feb  5 2021 Reinhard Max <max@suse.com>
- bsc#1181840: Same fix as for tkConfig.sh is needed for tk.pc.
* Fri Jan 29 2021 Reinhard Max <max@suse.com>
- bsc#1179615: TK_LIBS in tkConfig.sh possibly breaks build on
  newer service packs and is not needed for linking to a dynamic
  libtk anyway, so make it empty.
* Wed Sep 13 2017 max@suse.com
- Change licence to "TCL".
* Fri Aug 11 2017 max@suse.com
- New version 8.6.7:
  * (bug)[a2abc4] Wrong warp cursor position on 2nd display
  * (bug)[fa3229] menu-38.1
  * (bug)[2cf3d6] button-5.24
  * (bug)[1534455,2945130] Key release events get _L vs _R right.
  * (bug)[8c4216] listbox-4.1
  * (bug)[eb2681] listbox-13.1
  * (bug)[3126428] ttk::button react to image change
  * (bug)[1082213] wrapped text don't start lines with whitespace
  * (bug)[3217462] tri-state button on non-native theme
  * (bug)[3588460] Fix file dialog -typevariable
  * (bug)[e36963] event generate .e <diaeresis>
  * (bug)[6aea69] grid-23
  * (bug)[f60c54] combobox-3
  * (bug)[f32502] crash drawing many dashed objects
  * (bug)[dac92f] text-2.[89]
  * (bug)[7a838c] X11 ring buffer overflow
  * (bug)[d4fb4e] imgPhoto-4.75
  * (bug)[1403ea] Limits on text line size on Windows
  * (bug)[ae32eb] textDisp fails in text custom config
  * (bug)[7d967c] crash after IME restart
  * (bug)[c492c9] disabled combobox arrow appearance
  * (bug)[6b3644] Fix -alpha for 16-bit color PNG
  * (bug)[775273] artifacts on Ubuntu 16.10+
  * (bug)[28a3c3] test BTree memleaks plugged
  * (bug)[db8c54] Stop freed mem access in warp pointer callback
  * (bugs) Fix calculation of ttk::notebook tab widths
  * (bug)[291296] notebook tab management
  * (bug)[3f323b] variable struct size on XCode 8.3.1
  * (bug)[a5ba1c] race condition on Win clipboard cleanup
  * (bug)[2433781] center image on button
  * (bug)[434d29] type mismatch with recent Xft
  * (bug)[bc43fd] paneconfigure get pane heights right
  * (bug)[adc028] menu avoid unreleasable global grab
  * (bug)[92e028,c5eb90] User switch forced theme reset
  * (bug)[62c5b7] segfault in [text] replace
  * (bug)[b601ce] Resource exhaustion processing corrupt GIF
  * (bug)[28d0b8] Follow ICCCM advice on X selection protocol
  * (bug)[4966ca] Scidb race in notebook tab selection
* Mon Nov 14 2016 max@suse.com
- New version 8.6.6:
  * (bug)[3137232] spinbox teardown hygiene
  * (bug)[2981253] spinbox rapid button action
  * (bug)[2262543] scale initialization callbacks
  * (bug)[e9112e] incomplete [wm forget]
  * (bug)[d95e5d] <Map> from hidden panes
  * (TIP 443) More configuration options for text tags
  * (bug)[487861] menu: cascade/accelerator appearance
  * (bug)[1192095] active index from toplevel menus
  * (bug)[18c08d] revised final newline behavior in [text]
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[fd3a4d] <<Modified>> delivery to text peers
  * (bug)[b36218,011706] event reentrancy / widget destruction
  * (bug)[64261b] mouse events after double click
  * (bug)[545f10] Xft color font speed
  * (bug)[109865] event reentrancy / widget destruction
  * (TIP 446)[1273358] [$text edit (canundo|canredo)]
  * (bug)[79549a] crash in mouse pointer warping
  * (bug)[787adc] Modernize Tk_Init()
  * (bug) Aqua: excess lable padding
  * (bug) Aqua: bitmap distortion
  * (bug) Aqua/Retina: fix alpha rendering of images
  * (bug)[c84f66] Aqua: crash: overflow in geometry calc
  * (bug)[450bb0] Aqua: memory corruption from [tk busy]
* Tue Mar  1 2016 fweiss@suse.com
- New version 8.6.5:
  * (bug)[e4ed00] [$text index "1.0 display wordstart"] crash
  * (bug)[562118] Unicode support of "wordstart" modifier
  * (bug)[06c3fc] PNG alpha error corrupted output file
  * (bug)[dece63] various mem corruptions in images
  * (bug)[53f8fc] panedwindow geometry management
  * (bug)[1641721] tk_getOpenFile symlink display doubled
  * (bug)[d7bad5][2368195][3592454][1714535][1292219][3592454]
    panedwindow fixes
  * (bug)[805cff] Tk_ConfigureWidget() segfault
  * (bug)[3f179a] Text widget crash with elided text
  * (bug)[2886436] Stop [$text delete] acting before start index
  * (bug)[1236306] TraverseToMenu error bound to toplevel destroy
  * (bug)[00189c] MSVC 14: semi-static UCRT support
  * (bug)[cc0ba3] PNG read buffer overflow
  * (bug)[1501749] Crash embedded window delete bound to <Map>
  * (license) Replace icons that lacked clear free license
  * (bug)[46c83f] Win: tk_getOpenFile -initialdir
  * (new feature)[TIP 437] New panedwindow options
  * (bug)[1669632] [text] autoseparator placement
  * (bug)[2262711] [text] RE search Unicode+elided
  * (bug)[1815161] [$text count -ypixels] needs management
  * (bug)[1520118] Document spinbox validate expectations
  * (bug)[1414025] $entry insertion cursor visibility
  * (bug) PNG rendering on El Capitan
  * (bug)[2160206] menubutton panic
  * (bug)[220854] Display trailing TAB in entry
  * (bug)[542199] double click on lone char in entry
  * (bug)[297442d] strict motif binding on <Control-underscore>
  * (bug)[3601604] $listbox -takefocus
  * (bug)[1997299] [text] tag borderwidth leak
  * (bug)[1739605] [text see] misbehavior
  * (bug)[ff8a1e] Never-mapped [text] performance
  * (bug)[1700065] Report errors from -textvariable write trace
  * (bug)[793909] -textvariable handle undefined namespace
  * (bug)[2f78c7] crash with [text] and [tablelist]
  * (bug)[1288433,3102228] <<ListboxSelect>> misfires
  * (bug)[1510538] initial scrollbar width
  * (bug)[1305128] event not received by scrollbar
  * (bug)[1927212] Mousewheel/scrollbar bindings
  * (bug)[2049429] get more $text options from database
  * (TIP 441) New option [listbox ... -justify]
  * (bug) OBOE in ttk::notebook options parsing
  * (enhance) [option readile] expects utf-8 file
  * (bug) crash in [$text delete]
* Thu Aug  6 2015 max@suse.com
- New version 8.6.4:
  * (bug)[d43a10] shimmer-related crash in [tk_getOpenFile]
  * (bug)[1c0d6e] Win build trouble with SIGDN
  * (bug)[4a0451] [tk_getOpenFile] result
  * (bug) several fixes to elided context in [text]
  * (new feature)[TIP 433] %%M binding substitution
  * (bug)[ab6dab] corrupt dashed lines in postscript
- Update tkcon.tcl to CVS revision 1.122.
* Wed Nov 12 2014 max@suse.com
- New version 8.6.3:
  * (bug)[9e487e] Phony button clicks from browsers to plugin
  * (bug)[810c43] [text] elide changes advance epoch
  * (bug)[fb35eb] fix PNG transparency appearance
  * (bug)[3417012] [scale -digits $bigValue] segfault
  * (bug)[3529885] [scale] handling of negative resolution
* Thu Aug 28 2014 vwallfahrer@suse.com
- Update to 8.6.2:
  * Ocaml trouble with Tk and tailcall splice.
  * Accept [image create -format PNG] (upper case).
  * fix png wrong component indices
  * PNG parser accept uppercase -format
  * fix double free of a TkFont
  * support PPM maxval up to 65535
  * fix multi-interp font teardown double free
  * fix option file \n syntax support
  * X: correct fontconfig dependence
  * fix @TK_LIBS@ in pkgconfig
  * fix autoscroll initiation
* Mon Mar 31 2014 badshah400@gmail.com
- Add tk-fix-pkgconfig-file.patch to fix undefined linker flag
  (@TK_LIBS@) in tk.pc pkgconfig file; patch sent upstream, see
  https://core.tcl.tk/tcl/tktview?name=5bcb5026ad51abb7 .
* Tue Oct 22 2013 sndirsch@suse.com
- tkcon requires xhost (bnc#846953)
* Fri Sep 20 2013 max@suse.com
- Final 8.6.1 release:
  * Fix several crashes.
* Tue Sep 10 2013 kpetsch@suse.com
- New patchlevel release 8.6.1rc0:
  * (enhancement) better build support for Debian arch
  * (bug fix)[3603077] treeview update on tag add/remove
  * (bug fix)[3599312] First Alt key event is lost
  * (platform support) FreeBSD updates
* Thu Jun 20 2013 max@suse.com
- New version: 8.6.0.
  * Built-in PNG Image Support: Photo images now support
    read/write in the PNG format, with the ability to set the
    alpha channel.
  * Busy Windows: New command tk busy is a variant of blt::busy
    that lets the interactivity of windows be suspended and
    restored as required by the needs of the program.
  * New Font Selection Dialog Interface: New command tk
    fontchooser provides a portable interface to the standard font
    selector of the platform, whether that is modal or not.
  * Angled Text: New option -angle $degrees to $canvas create text
    for rotating displayed text.
  * Moving Things on a Canvas: New commands $canvas moveto,
    $canvas imove and $canvas rchars for moving and manipulating
    canvas items.
  * Additional New Features: Text widget cursor control, more
    window manager hints, and a collection of modernizations in
    appearance and function.
- Integrate tkcon.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Oct  5 2012 aj@suse.de
- Fix configure xft detection (add patch tk-8.5.12-fix-xft.patch).
- Replace build requires of xorg-x11-devel with those that are really
  needed.
* Thu Aug  9 2012 max@suse.com
- New patchlevel release 8.5.12:
  * [3437816] return code of [canvas lower]
  * [3021557] cursor freeze in elided text
  * [3476698] hang in [text mark prev/next]
  * [3475627] Stop text-31.11 failure
  * [1630271] hang/crash on mark before -startline
  * [1754043,2321450] -blockcursor appearance
  * [3480471] crash in [tk_getOpenFile]
  * [3480634] PNG image in menus
  * [2925561] disabled combobox don't take focus
  * [3486474] Correct color scaling
  * [1630262,1615425] [text] crash tags & -*line
  * [3497848] consistent pixel rounding
  * [3503317] XParseColor speedup
  * [3176239] control-Mousewheel crash
  * [3520202] <MouseWheel> %%k,%%K,%%N for Python
  * [533519] multiscreen window placement
  * [2768586] multiscreen menu posting
  * [1630254] text peer update on -startline reset
  * [3294450] ttk text element clipping
  * Make sure all index tables are static
  * [3546073] DisplayString() -> DefaultDisplay()
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov  8 2011 max@suse.com
- New patchlevel release 8.5.11:
  * [3341056] new crash in unset traces
  * [3314770] restore file dialog resizeability
  * [3404541] -takefocus option
  * [TIP 382] -confirmoverwrite on save dialog
  * [3410609] AltGr keysyms on Swiss keyboard
  * [3431491] improved "pixels" shimmer logic
- Add a manpage for wish8.5 by symlinking to the wish manpage.
- Remove unneeded %%clean section and norootforbuild comment.
- Add tk-upstream-fixes.patch with fixes for manpage bugs and
  a missing x-bit in the demo section.
* Fri Jul  1 2011 max@novell.com
- New patchlevel release 8.5.10:
  * (bug fix)[3057573] specify combobox text fg color
  * (bug fix)[2829363] [$tv see] open item -> sched display
  * (bug fix)[3085489] crash in [tag add/remove]
  * (enhancement) Updated German messages.
  * (platform) VS 2005 SP1 MSVC compiler
  * (bug fix)[3071836] crash in tk_getSaveFile
  * (bug fix)[3154705] tk_messageBox close button disabled
  * (enhancement) add [ttk::entry validate]
  * (bug fix)[3205260] crash in [wm manage]
  * (bug fix)[3181181] tearoff submenu fix
  * (bug fix)[3205464] [wm forget] loses window
  * (bug fix)[3223850] ttk button state disabled during click
  * (bug fix)[3000002] ttk scrollbar size Appearance
  * (bug fix)[3239768] Win menu font support
  * (bug fix)[3129527] stop buffer overflows
  * (feature change)[2997657] No -container for [labelframe]
  * (bug fix)[723765] [grid remove] lost -in value
  * (bug fix)[3291543] mem corrupt when [$canvas dchars] removes
    all coords of a polygon
  * (bug fix)[2949774] cascade menu unpost
  * (bug fix)[2546087] [console] treatment of '\0'
  * (bug fix)[2358545] Restore "08" in spinbox configured with
  - from and -to (porter)
  * (bug fix)[2484771] modal dialog settings
  * (bug fix)[3175610] incomplete line item refresh
  * (bug fix)[3062331] crash in unset traces
- tk-xft.patch has been integrated upstream.
* Tue Mar  8 2011 max@novell.com
- Fix libXft detection in configure.
* Fri Sep  3 2010 max@suse.de
- Bugfix release: 8.5.9:
  * [sf#2899949] crash on widget destroy
  * [sf#2902814] fix [wm iconphoto] on LP64 systems
  * [sf#2548661] crash in GetFontFamilyName
  * [sf#2864685] Compiz menu item animation
  * [sf#2902573] Update Safe Tk to new Safe Base
  * [sf#2912473] accept :: in DISPLAY name
  * [sf#2496162] crash calling Tk_DeleteOptionTable()
  * [sf#2917663] [send] accept SI:* on auth list
  * [sf#2919205] syntax bug in [tk_messageBox]
  * [sf#2912356] [ttk::sizegrip] accommodate Compiz
  * [sf#2879927] Win: cascade menu highlight
  * [sf#1924761] stop [event generate] / XIM conflict
  * [sf#2848897] ODS_NOACCEL flag support
  * [sf#220950] [$menu delete] bounds check
  * [sf#2898255] unlimited multi-file select
  * [sf#1163496] X: [wm transient] fix
  * [TIP 360] Modernize X11 Menus
  * [sf#2932808] canvas update on state change
  * [sf#2931374] overflow in complex tag search
  * [TIP 359] Extended Window Manager Hint Support
  * [sf#2952745] crash in menu deletion
  * [sf#2968379] crash in peer text dump
  * [sf#3006842] crash on empty bind scripts
  * entry validation compat with Itcl scope
  * [sf#2585265] text <Delete>,<Backspace> note selection
  * [sf#3053320] update Ttk to tile 0.8.6 feature set
* Fri Nov 20 2009 max@suse.de
- Bugfix-Release 8.5.8:
  * [sf#2080533] panedwindow sash draw crash
  * [sf#2504402] iconphoto on non-32-bit displays
  * [sf#2785744] broken flag twiddling
  * [sf#2791352] XLFD parsing error
  * [sf#1923684] confused checkbutton state
  * [sf#2799589] crash on delayed window activation
  * [sf#220935] canvas dash update problem
  * [sf#2821962] photo image copy/paste
  * [sf#2496114] focus in dead window crash
  * [sf#2830420] X iconphoto for big endian
  * Fix word-wrap of non-breaking space in [text]
  * Fix tk::MessageBox bindings for ttk::buttons
  * [sf#1909931] [send] update for Fedora 8
  * Fix font allocation crash
  * Fix grayscale from images
  * [sf#2088597] min scrollbar slider size
  * [sf#2787164] combobox/menubutton arrow size
  * [sf#2870648] file dialog cursor
  * [sf#1961455] underline, overstrike Xft fonts
  * [sf#2794032] permit [load] into Tcl 8.6+ interps
  * [sf#2168768] file dialog -typevariable scope
  * [sf#1469210] [text] modified error
  * [sf#1530276] X checkbutton -selectcolor
  * [sf#1854913] [.t delete] before -startindex
  * [sf#2809525] prevent X crash on overlong color name
  * [sf#2891541] fix grab behaviour for main window
* Tue Jun 16 2009 max@suse.de
- Install binaries unstripped to fix debuginfo packages
* Mon May 11 2009 max@suse.de
- New version: 8.5.7
  * Improve keyboard bindings for ttk::scale.
  * Permit [text] names containing "-".
  * Limit [wm manage] to Frames.
  * Fix Tk_Create*ImageType() thread safety.
  * Eliminate unnecessary units conversion in screen distances,
    reducing precision loss.
  * Fix crash on XCreateIC failure.
  * Fax crash in Tk_MakeWindowExist().
  * More bug fixes and improvements.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Dec  8 2008 max@suse.de
- Added an explicit requirement for xorg-x11-libX11-devel, because
  tk.h needs some of the header files.
* Wed Oct 15 2008 max@suse.de
- Bugfix release 8.5.5:
  * fix [tk_getOpenFile -multiple 1] on unix
  * Relax interdependency between Tcl 8.5.x and Tk 8.5.x releases.
  * default menu cursor: no more Motif
  * arguments passed to -[xy]scrollcommand callbacks, and values
    returned by [xy]view methods are explicitly formatted as
    doubles.
  * format double values explicitly in double format, avoiding
    sensitivity to locale setting.
* Mon Sep  8 2008 max@suse.de
- New version: 8.5.4:
  * fix a crash in [ttk::scale]
  * fix portability of [winfo id]
  * fix unmapped toplevel crashes
  * Tk header files revised to accommodate incompatible changes
    in recent X.org releases of X11 headers.
* Thu Jul 10 2008 max@suse.de
- New version: 8.5.3:
  * Fix Tk_ParseArgv() double free crash.
  * Fix wish -h mem explosion
  * Fix canvas item <Enter> events
  * Fix ttk::label height or width 0 panic
  * Use Xutf8LookupString when possible
  * Fix global grab segfault
- Added workaround for problems with new GenericEvent added by
  xproto-7.0.13.
* Wed Apr  2 2008 max@suse.de
- New version: 8.5.2:
  * New modern theming engine: New and complementary widgets that
    make use of platform-specific theming on Mac OS X and Windows
    to better fit in with those environments, and feature an
    improved look and feel under X11.
  * New widgets: Part of the themed widget set, Tk now has core
    notebook, combobox, treeview and progressbar widgets.
  * text widget: Smooth scrolling, widget peering, and improved
    procedures for counting and replacing text.
  * Font rendering: Now uses anti-aliased text under X11, and a
    more modern text engine (ATSUI) on Mac OS X.
  * Additional improvements: Window transparency, new fullscreen
    option for windows, enhancements to specific widgets and
    window layout, and more.
- Adjusted paths according to the new Tcl extension layoout.
* Tue Sep 11 2007 max@suse.de
- Fix a crash with multi-frame interlaced GIFs (#309607).
* Wed Jun  6 2007 max@suse.de
- New patchlevel release: 8.4.15
- improve performance of [$listbox itemconfigure]
- use fd_mask for 64bit support
- fix [tk_getOpenFile] in empty dir
- fix list shimmer crash [grid *configure]
* Tue Oct 17 2006 max@suse.de
- New patchlevel release: 8.4.14rc2
- Fix crash on invalid font name from XServer
- Unmap canvas window items on canvas Unmap
- Fix [listbox] crash with namespace var
- Fix [console] std chan refcount
- Fix [console] thread safety
- Prevent excess variable writes by [scale]
- Add WM_UNICHAR window message
- Improve speed on [text] delete
- Alignment fixes in ucs-2be encoding routines
* Thu Sep 14 2006 max@suse.de
- New version: 8.4.13
- Fixes the SCIM issues (#77424, obsoletes tk-scim.patch)
- Speeds up photo image updates.
- Fixes a crash in animated GIFs.
* Wed Aug 16 2006 aj@suse.de
- Replace xorg-x11-devel BuildRequires with really needed libs.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 max@suse.de
- Finally fixed the SCIM issues (#77424).
* Fri Dec  9 2005 max@suse.de
- New version: 8.4.12.
- Enabled support for multithreading.
* Sun Nov  6 2005 schwab@suse.de
- Fix syntax error in unix configure script.
* Tue Sep  6 2005 max@suse.de
- Disabled the SCIM patch, because it causes some focus problems.
- Added a workaround that prevents Tk from using SCIM, so that at
  least normal keyboard input is possible (#77424).
* Fri Sep  2 2005 max@suse.de
- Added tk-scim.patch to improve XIM support and make Tk work
  correctly with SCIM (#77424).
* Fri Jul 29 2005 max@suse.de
- Re-added tkUnixDefault.h to tk-devel. It is needed by Tix.
* Wed Jul 27 2005 max@suse.de
- New version: 8.4.11.
* Tue Jun 14 2005 max@suse.de
- New version 8.4.10.
- Moved script libraries to /usr/share/tcl .
* Mon Mar 21 2005 max@suse.de
- Fixed a small typo in the trigger script.
* Mon Mar 21 2005 max@suse.de
- Added prerequisites for the trigger scripts (bug #74027).
* Fri Mar 18 2005 max@suse.de
- Make sure that tk-32bit finds the script libraries when
  installed on a 64bit system.
* Fri Dec  3 2004 max@suse.de
- New version: 8.4.9
* Mon Nov 22 2004 max@suse.de
- New version: 8.4.8
* Fri Jul 30 2004 max@suse.de
- New 8.4.7 tarball with a last-minute fix for broken Compose key.
* Wed Jul 28 2004 max@suse.de
- New version: 8.4.7
* Fri Mar  5 2004 max@suse.de
- Updated to the official 8.4.6 release tarball.
* Fri Feb 27 2004 max@suse.de
- New version: 8.4.6
* Fri Feb  6 2004 max@suse.de
- Added -fno-strict-aliasing to CFLAGS.
* Mon Feb  2 2004 max@suse.de
- Building as a non-root user.
* Thu Jan 15 2004 max@suse.de
- Package Tk internal headers again. They are still needed by some
  packages (e.g. tix).
* Mon Jan 12 2004 max@suse.de
- New version: 8.4.5
- Cleaned up the spec file.
* Tue Sep  2 2003 max@suse.de
- Disabled building of the static library to save build time and
  CD space.
* Wed Jul 23 2003 max@suse.de
- New version: 8.4.4
- Split into tk and tk-devel.
* Wed May 21 2003 max@suse.de
- New version: 8.4.3
- Removed obsolete patches.
* Wed Mar  5 2003 max@suse.de
- Updated to official 8.4.2 release tarball.
- Added essential diff to RC1 as tk-20030305.patch.bz2.
* Fri Feb 28 2003 max@suse.de
- Updated to 8.4.2 RC1, and added an essential diff to the
  previous tarball (tk-20030227.patch.bz2).
* Wed Feb 19 2003 max@suse.de
- Updated to CVS HEAD, and added diff to previous verssion
  for completeness.
- Fixes several bugs, see ChangeLog for details.
* Fri Feb  7 2003 max@suse.de
- Upgrade to CVS HEAD (8.4.2pre).
* Tue Nov 26 2002 max@suse.de
- Included private header files (needed for Tix).
* Tue Nov 26 2002 max@suse.de
- New version: 8.4.1
- Added tk-HEAD.patch with fixes that went in after the release.
- Moved the Tk sources back into a separate package, now that Tk
  can be built without access to the Tcl source tree.
- For the changes of the last four years see tcl.changes in the
  tcl package.
* Tue Nov 24 1998 max@suse.de
- merged spec-files into tcl_new.spec
* Mon Nov 23 1998 max@suse.de
- new version: 8.0.4
- cleand up softlinks and compression for man pages
* Thu Jan  8 1998 hf@suse.de
- bugfix for missing tkConfig8.0.sh
* Mon Nov 10 1997 hf@suse.de
- new version 8.0p1
* Wed Oct 15 1997 hf@suse.de
- ready for autobuild
* Thu Jul  3 1997 hf@suse.de
- A new version 8.0b2. The second (and probably last) beta release of
  Tk 8.0.
* Tue Jun  3 1997 hf@suse.de
- added static librs and all links for the manpages in
  the /usr/doc/packages/tk8.0/man
* Fri May 16 1997 hf@suse.de
- added new link
* Mon May 12 1997 hf@suse.de
- added new patch invisible.patch
* Tue Apr 15 1997 hf@suse.de
- Manpages hardlinks removed and added softlinks to compressd manpages
- The new directory for the manpages is /usr/doc/packeges/tcl8.0/man
